@@ -12,7 +12,7 @@ import tempfile
 @contextlib.contextmanager
 def atomic_write(filename, text=True, keep=True,
                  owner=None, group=None, perms=None,
-                 suffix='.bak', prefix='tmp', store_loc='./'):
+                 suffix='.bak', prefix='tmp_', store_loc='./'):
     """Context manager for overwriting a file atomically.
 
     Usage:
